@@ -4,8 +4,9 @@
 #' @export
 #' @importFrom logger log_level
 logger_tester_function <- function(level, msg) {
-    x <- runif(1)
-    log_level(level, '{msg} {x}')
+  set.seed(1014)
+  x <- runif(1)
+  log_level(level, "{msg} {x}")
 }
 
 #' Testing logging INFO from package
@@ -13,6 +14,6 @@ logger_tester_function <- function(level, msg) {
 #' @export
 #' @importFrom logger log_info
 logger_info_tester_function <- function(msg) {
-    everything <- 42
-    log_info('{msg} {everything}')
+  everything <- 42
+  log_info("{msg} {everything}")
 }
